@@ -149,11 +149,11 @@ class Selenium(Scraper):
 
     def on_hover(self, path: str, element: any) -> None:
         element = self.xPath(element=element, path=path)
-        ActionChains(self.scraper.scraper.driver).move_to_element(element).perform()
+        ActionChains(self.driver).move_to_element(element).perform()
 
     def on_click_and_hold(self, path: str, seconds: float, element: any=None, timeout: int=0) -> None:
         element = self.xPath(path=path, timeout=timeout)
-        action = ActionChains(self.scraper.driver)
+        action = ActionChains(self.driver)
         action.click_and_hold(element).perform()
         time.sleep(seconds) # sleep for N seconds
         action.release().perform()
